EXPORTS
	?SetAudioRoutingObserver@CMusEngSession@@QAEXPAVMMusEngAudioRoutingObserver@@@Z @ 1 NONAME ; void CMusEngSession::SetAudioRoutingObserver(class MMusEngAudioRoutingObserver *)
	?ParseUriL@TMusEngUriParser@@QAEXXZ @ 2 NONAME ; void TMusEngUriParser::ParseUriL(void)
	?EnableLoudspeakerL@CMusEngSession@@QAEXHH@Z @ 3 NONAME ; void CMusEngSession::EnableLoudspeakerL(int, int)
	?CancelInviteL@CMusEngMceOutSession@@QAEXXZ @ 4 NONAME ; void CMusEngMceOutSession::CancelInviteL(void)
	?SetClipL@CMusEngClipSession@@QAEXABVTDesC16@@@Z @ 5 NONAME ; void CMusEngClipSession::SetClipL(class TDesC16 const &)
	?VolumeL@CMusEngSession@@QBEHXZ @ 6 NONAME ; int CMusEngSession::VolumeL(void) const
	?IsMicMutedL@CMusEngSession@@QAEHXZ @ 7 NONAME ; int CMusEngSession::IsMicMutedL(void)
	?FastRewindL@CMusEngClipSession@@QAEXH@Z @ 8 NONAME ; void CMusEngClipSession::FastRewindL(int)
	?ZoomDefaultL@CMusEngLiveSession@@QAEXXZ @ 9 NONAME ; void CMusEngLiveSession::ZoomDefaultL(void)
	?GetUri16L@TMusEngUriParser@@QAEPAVHBufC16@@H@Z @ 10 NONAME ; class HBufC16 * TMusEngUriParser::GetUri16L(int)
	?VolumeUpL@CMusEngSession@@UAEXXZ @ 11 NONAME ; void CMusEngSession::VolumeUpL(void)
	?UriType@TMusEngUriParser@@QAE?AW4TMusEngUriType@1@XZ @ 12 NONAME ; enum TMusEngUriParser::TMusEngUriType TMusEngUriParser::UriType(void)
	?IsMutedL@CMusEngMceSession@@QAEHXZ @ 13 NONAME ; int CMusEngMceSession::IsMutedL(void)
	?DurationL@CMusEngClipSession@@QAE?AVTTimeIntervalSeconds@@XZ @ 14 NONAME ; class TTimeIntervalSeconds CMusEngClipSession::DurationL(void)
	??0TMusEngUriParser@@QAE@ABVTDesC16@@@Z @ 15 NONAME ; TMusEngUriParser::TMusEngUriParser(class TDesC16 const &)
	?AcceptInvitationL@CMusEngReceiveSession@@QAEXABH@Z @ 16 NONAME ; void CMusEngReceiveSession::AcceptInvitationL(int const &)
	?CurrentZoomL@CMusEngLiveSession@@QBEHXZ @ 17 NONAME ; int CMusEngLiveSession::CurrentZoomL(void) const
	?MinBrightnessL@CMusEngLiveSession@@QBEHXZ @ 18 NONAME ; int CMusEngLiveSession::MinBrightnessL(void) const
	?GetUri8L@TMusEngUriParser@@QAEPAVHBufC8@@XZ @ 19 NONAME ; class HBufC8 * TMusEngUriParser::GetUri8L(void)
	?NewL@CMusEngLiveSession@@SAPAV1@ABVTRect@@AAVMMusEngSessionObserver@@AAVMMusEngOutSessionObserver@@AAVMMusEngLiveSessionObserver@@I@Z @ 20 NONAME ; class CMusEngLiveSession * CMusEngLiveSession::NewL(class TRect const &, class MMusEngSessionObserver &, class MMusEngOutSessionObserver &, class MMusEngLiveSessionObserver &, unsigned int)
	?UnmuteL@CMusEngMceSession@@UAEXXZ @ 21 NONAME ; void CMusEngMceSession::UnmuteL(void)
	?AudioRoutingCanBeChanged@CMusEngSession@@QAEHXZ @ 22 NONAME ; int CMusEngSession::AudioRoutingCanBeChanged(void)
	?MaxBrightnessL@CMusEngLiveSession@@QBEHXZ @ 23 NONAME ; int CMusEngLiveSession::MaxBrightnessL(void) const
	?MinZoomL@CMusEngLiveSession@@QBEHXZ @ 24 NONAME ; int CMusEngLiveSession::MinZoomL(void) const
	?VolumeDownL@CMusEngSession@@UAEXXZ @ 25 NONAME ; void CMusEngSession::VolumeDownL(void)
	?OrientationL@CMusEngMceSession@@QAE?AW4TDisplayOrientation@1@XZ @ 26 NONAME ; enum CMusEngMceSession::TDisplayOrientation CMusEngMceSession::OrientationL(void)
	?SetSupportedVideoCodecListL@CMusEngMceOutSession@@QAEXABVTDesC16@@@Z @ 27 NONAME ; void CMusEngMceOutSession::SetSupportedVideoCodecListL(class TDesC16 const &)
	?MuteL@CMusEngMceSession@@UAEXXZ @ 28 NONAME ; void CMusEngMceSession::MuteL(void)
	?IsRecording@CMusEngLiveSession@@QAEHXZ @ 29 NONAME ; int CMusEngLiveSession::IsRecording(void)
	?SetVolumeL@CMusEngSession@@UAEXH@Z @ 30 NONAME ; void CMusEngSession::SetVolumeL(int)
	?DecreaseBrightnessL@CMusEngLiveSession@@QAEXXZ @ 31 NONAME ; void CMusEngLiveSession::DecreaseBrightnessL(void)
	?CancelTranscodeL@CMusEngClipSession@@QAEXXZ @ 32 NONAME ; void CMusEngClipSession::CancelTranscodeL(void)
	?PauseL@CMusEngClipSession@@UAEXXZ @ 33 NONAME ; void CMusEngClipSession::PauseL(void)
	?BrightnessDefaultL@CMusEngLiveSession@@QAEXXZ @ 34 NONAME ; void CMusEngLiveSession::BrightnessDefaultL(void)
	?FastForwardL@CMusEngClipSession@@QAEXH@Z @ 35 NONAME ; void CMusEngClipSession::FastForwardL(int)
	?SetZoomL@CMusEngLiveSession@@QAEXH@Z @ 36 NONAME ; void CMusEngLiveSession::SetZoomL(int)
	?SetRectL@CMusEngSession@@QAEXABVTRect@@@Z @ 37 NONAME ; void CMusEngSession::SetRectL(class TRect const &)
	?NewL@CMusEngClipSession@@SAPAV1@ABVTRect@@AAVMMusEngSessionObserver@@AAVMMusEngOutSessionObserver@@AAVMMusEngClipSessionObserver@@I@Z @ 38 NONAME ; class CMusEngClipSession * CMusEngClipSession::NewL(class TRect const &, class MMusEngSessionObserver &, class MMusEngOutSessionObserver &, class MMusEngClipSessionObserver &, unsigned int)
	?BrightnessAutoL@CMusEngLiveSession@@QAEXXZ @ 39 NONAME ; void CMusEngLiveSession::BrightnessAutoL(void)
	?IncreaseBrightnessL@CMusEngLiveSession@@QAEXXZ @ 40 NONAME ; void CMusEngLiveSession::IncreaseBrightnessL(void)
	?InviteL@CMusEngMceOutSession@@QAEXABVTDesC16@@@Z @ 41 NONAME ; void CMusEngMceOutSession::InviteL(class TDesC16 const &)
	?SetOrientationL@CMusEngMceSession@@QAEXW4TDisplayOrientation@1@@Z @ 42 NONAME ; void CMusEngMceSession::SetOrientationL(enum CMusEngMceSession::TDisplayOrientation)
	?IsLoudSpeakerEnabled@CMusEngSession@@QBEHXZ @ 43 NONAME ; int CMusEngSession::IsLoudSpeakerEnabled(void) const
	?ContainsAudioL@CMusEngMceSession@@QAEHXZ @ 44 NONAME ; int CMusEngMceSession::ContainsAudioL(void)
	?NewL@CMusEngReceiveSession@@SAPAV1@ABVTRect@@AAVMMusEngSessionObserver@@AAVMMusEngReceiveSessionObserver@@@Z @ 45 NONAME ; class CMusEngReceiveSession * CMusEngReceiveSession::NewL(class TRect const &, class MMusEngSessionObserver &, class MMusEngReceiveSessionObserver &)
	?VolumeUpL@CMusEngMceSession@@UAEXXZ @ 46 NONAME ; void CMusEngMceSession::VolumeUpL(void)
	?IsPlayingL@CMusEngClipSession@@UAEHXZ @ 47 NONAME ; int CMusEngClipSession::IsPlayingL(void)
	?PlayL@CMusEngClipSession@@UAEXXZ @ 48 NONAME ; void CMusEngClipSession::PlayL(void)
	?ZoomInL@CMusEngLiveSession@@QAEXXZ @ 49 NONAME ; void CMusEngLiveSession::ZoomInL(void)
	?PauseL@CMusEngLiveSession@@UAEXXZ @ 50 NONAME ; void CMusEngLiveSession::PauseL(void)
	?GetSessionTime@CMusEngMceSession@@QBE?AVTTimeIntervalSeconds@@XZ @ 51 NONAME ; class TTimeIntervalSeconds CMusEngMceSession::GetSessionTime(void) const
	?SetVolumeL@CMusEngMceSession@@UAEXH@Z @ 52 NONAME ; void CMusEngMceSession::SetVolumeL(int)
	?Rect@CMusEngSession@@QBE?AVTRect@@XZ @ 53 NONAME ; class TRect CMusEngSession::Rect(void) const
	?SetBrightnessL@CMusEngLiveSession@@QBEXH@Z @ 54 NONAME ; void CMusEngLiveSession::SetBrightnessL(int) const
	?TranscodeL@CMusEngClipSession@@QAEXABV?$TBuf@$0BAA@@@@Z @ 55 NONAME ; void CMusEngClipSession::TranscodeL(class TBuf<256> const &)
	?MaxZoomL@CMusEngLiveSession@@QBEHXZ @ 56 NONAME ; int CMusEngLiveSession::MaxZoomL(void) const
	?VolumeDownL@CMusEngMceSession@@UAEXXZ @ 57 NONAME ; void CMusEngMceSession::VolumeDownL(void)
	?ZoomOutL@CMusEngLiveSession@@QAEXXZ @ 58 NONAME ; void CMusEngLiveSession::ZoomOutL(void)
	?ConnectionActive@CMusEngMceSession@@QBEHXZ @ 59 NONAME ; int CMusEngMceSession::ConnectionActive(void) const
	?PositionL@CMusEngClipSession@@QAE?AVTTimeIntervalSeconds@@XZ @ 60 NONAME ; class TTimeIntervalSeconds CMusEngClipSession::PositionL(void)
	?MuteMicL@CMusEngSession@@QAEXH@Z @ 61 NONAME ; void CMusEngSession::MuteMicL(int)
	?NewL@CMusEngLiveSession@@SAPAV1@ABVTDesC16@@ABVTRect@@AAVMMusEngSessionObserver@@AAVMMusEngOutSessionObserver@@AAVMMusEngLiveSessionObserver@@I@Z @ 62 NONAME ; class CMusEngLiveSession * CMusEngLiveSession::NewL(class TDesC16 const &, class TRect const &, class MMusEngSessionObserver &, class MMusEngOutSessionObserver &, class MMusEngLiveSessionObserver &, unsigned int)
	?EnableDisplayL@CMusEngMceSession@@UAEXH@Z @ 63 NONAME ; void CMusEngMceSession::EnableDisplayL(int)
	?CurrentBrightnessL@CMusEngLiveSession@@QBEHXZ @ 64 NONAME ; int CMusEngLiveSession::CurrentBrightnessL(void) const
	?RecordL@CMusEngLiveSession@@QAEXH@Z @ 65 NONAME ; void CMusEngLiveSession::RecordL(int)
	?IsPlayingL@CMusEngLiveSession@@UAEHXZ @ 66 NONAME ; int CMusEngLiveSession::IsPlayingL(void)
	?TerminateL@CMusEngMceSession@@QAEXXZ @ 67 NONAME ; void CMusEngMceSession::TerminateL(void)
	?PlayL@CMusEngLiveSession@@UAEXXZ @ 68 NONAME ; void CMusEngLiveSession::PlayL(void)
	?SetPositionL@CMusEngClipSession@@QAEXABVTTimeIntervalSeconds@@@Z @ 69 NONAME ; void CMusEngClipSession::SetPositionL(class TTimeIntervalSeconds const &)

